==> ejc-quality-impl-3.0.0-20240805.091544-68-sources.jar: com/ejianc/business/quality/model/vo/ReleaseUnitSettingsDetailVo.java <==
package com.ejianc.business.quality.model.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * @Author: LCL
 * @Date: 2024/7/23 下午3:05
 * @Description: 下达单位设置详情
 */
public class ReleaseUnitSettingsDetailVo extends BaseVO {

    /**
     * 所属类型(管理评审输入、经验反馈)
     */
    private String type;

    /**
     * 下达单位
     */
    private Long releaseUnits;
    private String releaseUnitsName;

    /**
     * 负责人
     */
    private String charge;
    private String chargeName;

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getReleaseUnits() {
        return releaseUnits;
    }

    @ReferDeserialTransfer
    public void setReleaseUnits(Long releaseUnits) {
        this.releaseUnits = releaseUnits;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public String getCharge() {
        return charge;
    }


    @ReferDeserialTransfer
    public void setCharge(String charge) {
        this.charge = charge;
    }

    public String getReleaseUnitsName() {
        return releaseUnitsName;
    }

    public void setReleaseUnitsName(String releaseUnitsName) {
        this.releaseUnitsName = releaseUnitsName;
    }

    public String getChargeName() {
        return chargeName;
    }

    public void setChargeName(String chargeName) {
        this.chargeName = chargeName;
    }
}

==> ejc-quality-impl-3.0.0-20250218.084522-124-sources.jar: com/ejianc/business/quality/model/vo/ReleaseUnitSettingsDetailVo.java <==
package com.ejianc.business.quality.model.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * @Author: LCL
 * @Date: 2024/7/23 下午3:05
 * @Description: 下达单位设置详情
 */
@SuppressWarnings({"LombokSetterMayBeUsed", "unused", "LombokGetterMayBeUsed"})
public class ReleaseUnitSettingsDetailVo extends BaseVO {

    /**
     * 所属类型(管理评审输入、经验反馈)
     */
    private String type;

    /**
     * 下达单位
     */
    private Long releaseUnits;
    private String releaseUnitsName;

    /**
     * 负责人
     */
    private String charge;
    private String chargeName;

    /**
     * 领导
     */
    private String leader;
    private String leaderName;

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getReleaseUnits() {
        return releaseUnits;
    }

    @ReferDeserialTransfer
    public void setReleaseUnits(Long releaseUnits) {
        this.releaseUnits = releaseUnits;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public String getCharge() {
        return charge;
    }


    @ReferDeserialTransfer
    public void setCharge(String charge) {
        this.charge = charge;
    }


    public String getReleaseUnitsName() {
        return releaseUnitsName;
    }

    public void setReleaseUnitsName(String releaseUnitsName) {
        this.releaseUnitsName = releaseUnitsName;
    }

    public String getChargeName() {
        return chargeName;
    }

    public void setChargeName(String chargeName) {
        this.chargeName = chargeName;
    }

    public String getLeaderName() {
        return leaderName;
    }

    public void setLeaderName(String leaderName) {
        this.leaderName = leaderName;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public String getLeader() {
        return leader;
    }

    @ReferDeserialTransfer
    public void setLeader(String leader) {
        this.leader = leader;
    }
}
